@@ -91,7 +91,7 @@ def ensemble_model_weighted(weights, models_list, testTFdataset, classification_
     return preds
 
 
-def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Averaging', classification_type = 'mutliclass'):
+def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Averaging', classification_type = 'mutliclass', weights = None):
 	import numpy as np
 	if ensemble_type == 'Model Averaging':
 		print("Computing predictions through Model Averaging")
@@ -109,11 +109,13 @@ def ensemble_predictions(models_list,  testTFdataset, ensemble_type = 'Model Ave
 		print("Predictions obtained with the output filename as -> ensemble_model_average")
 
 	elif ensemble_type == 'Model Weighted':
-		print("Please enter the weights by which the models should be ensembled.(sum = 1) Format -> comma seperated -> ")
-		weights = input()
-		weights = weights.split(',')
-		weights = [float(i) for i in weights]
-
+		if weights is None:
+			print("Weights not defined for Model Weighted..Exiting...\n Please define weights in a list such that sum(weights) = 1.")
+			return
+			
+		if len(weights) != len(models_list):
+			print("Length of weights doesn't match length of models_list... Exiting...")
+			return 
 		print("Computing predictions through Model Weighted")
 		preds =  ensemble_model_weighted(weights, models_list, testTFdataset, classification_type)
 
